.. role:: hidden
    :class: hidden-section

ax.service
==========

.. automodule:: ax.service
.. currentmodule:: ax.service


Ax Client
~~~~~~~~~

.. automodule:: ax.service.ax_client
    :members:
    :undoc-members:
    :show-inheritance:

Managed Loop
~~~~~~~~~~~~

.. automodule:: ax.service.managed_loop
    :members:
    :undoc-members:
    :show-inheritance:

Interactive Loop
~~~~~~~~~~~~~~~~

.. automodule:: ax.service.interactive_loop
    :members:
    :undoc-members:
    :show-inheritance:


Scheduler
~~~~~~~~~

.. automodule:: ax.service.scheduler
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: ax.service.utils.scheduler_options
    :members:
    :undoc-members:
    :show-inheritance:

Utils
-----

Best Point Identification
~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.service.utils.best_point_mixin
    :members:
    :undoc-members:
    :show-inheritance:


.. automodule:: ax.service.utils.best_point
    :members:
    :undoc-members:
    :show-inheritance:


Instantiation
~~~~~~~~~~~~~

.. automodule:: ax.service.utils.instantiation
    :members:
    :undoc-members:
    :show-inheritance:


Reporting
~~~~~~~~~

.. automodule:: ax.service.utils.report_utils
    :members:
    :undoc-members:
    :show-inheritance:


WithDBSettingsBase
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.service.utils.with_db_settings_base
    :members:
    :undoc-members:
    :show-inheritance:


EarlyStopping
~~~~~~~~~~~~~

.. automodule:: ax.service.utils.early_stopping
    :members:
    :undoc-members:
    :show-inheritance:
